##  Quality Seal States
  * Check needed: Indicates that the quality seal is broken and verification is required due to changes made by users who are not responsible or accountable for the fact sheet.
  * Approved: Indicates that the fact sheet has been reviewed and approved by the responsible or accountable user.
  * Draft: Indicates that the fact sheet is not yet finalized or approved. This is an additional state that can be enabled by the admin. When enabled, all new fact sheets with mandatory attributes will be created in the draft state.
  * Rejected: This is an additional state that can be enabled by the admin. This state can indicate that the fact sheet is being removed from the data quality process, and there is no need to maintain it further.
